# mypy-boto3-elasticache

[![PyPI - mypy-boto3-elasticache](https://img.shields.io/pypi/v/mypy-boto3-elasticache.svg?color=blue)](https://pypi.org/project/mypy-boto3-elasticache)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-elasticache.svg?color=blue)](https://pypi.org/project/mypy-boto3-elasticache)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-elasticache](#mypy-boto3-elasticache)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)


Type annotations for
[boto3.ElastiCache 1.13.24](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-elasticache](#mypy-boto3-elasticache)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ElastiCache` service.

```bash
python -m pip install boto3-stubs[elasticache]

# update installed packages index for automated type discovery
python -m mypy_boto3
```

Use `boto3` with `mypy_boto3_elasticache` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_elasticache import ElastiCacheClient

# Now mypy can check if your code is valid.
client: ElastiCacheClient = boto3.client("elasticache")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ElastiCacheClient = session.client("elasticache")



# Waiters are also supported

import mypy_boto3_elasticache.waiter as elasticache_waiters

cache_cluster_available_waiter: elasticache_waiters.CacheClusterAvailableWaiter = client.get_waiter("cache_cluster_available")
cache_cluster_deleted_waiter: elasticache_waiters.CacheClusterDeletedWaiter = client.get_waiter("cache_cluster_deleted")
replication_group_available_waiter: elasticache_waiters.ReplicationGroupAvailableWaiter = client.get_waiter("replication_group_available")
replication_group_deleted_waiter: elasticache_waiters.ReplicationGroupDeletedWaiter = client.get_waiter("replication_group_deleted")


# Annotated paginators are included as well

import mypy_boto3_elasticache.paginator as elasticache_paginators

describe_cache_clusters_paginator: elasticache_paginators.DescribeCacheClustersPaginator = client.get_paginator("describe_cache_clusters")
describe_cache_engine_versions_paginator: elasticache_paginators.DescribeCacheEngineVersionsPaginator = client.get_paginator("describe_cache_engine_versions")
describe_cache_parameter_groups_paginator: elasticache_paginators.DescribeCacheParameterGroupsPaginator = client.get_paginator("describe_cache_parameter_groups")
describe_cache_parameters_paginator: elasticache_paginators.DescribeCacheParametersPaginator = client.get_paginator("describe_cache_parameters")
describe_cache_security_groups_paginator: elasticache_paginators.DescribeCacheSecurityGroupsPaginator = client.get_paginator("describe_cache_security_groups")
describe_cache_subnet_groups_paginator: elasticache_paginators.DescribeCacheSubnetGroupsPaginator = client.get_paginator("describe_cache_subnet_groups")
describe_engine_default_parameters_paginator: elasticache_paginators.DescribeEngineDefaultParametersPaginator = client.get_paginator("describe_engine_default_parameters")
describe_events_paginator: elasticache_paginators.DescribeEventsPaginator = client.get_paginator("describe_events")
describe_global_replication_groups_paginator: elasticache_paginators.DescribeGlobalReplicationGroupsPaginator = client.get_paginator("describe_global_replication_groups")
describe_replication_groups_paginator: elasticache_paginators.DescribeReplicationGroupsPaginator = client.get_paginator("describe_replication_groups")
describe_reserved_cache_nodes_paginator: elasticache_paginators.DescribeReservedCacheNodesPaginator = client.get_paginator("describe_reserved_cache_nodes")
describe_reserved_cache_nodes_offerings_paginator: elasticache_paginators.DescribeReservedCacheNodesOfferingsPaginator = client.get_paginator("describe_reserved_cache_nodes_offerings")
describe_service_updates_paginator: elasticache_paginators.DescribeServiceUpdatesPaginator = client.get_paginator("describe_service_updates")
describe_snapshots_paginator: elasticache_paginators.DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
describe_update_actions_paginator: elasticache_paginators.DescribeUpdateActionsPaginator = client.get_paginator("describe_update_actions")
```

## Automated type discovery

`mypy_boto3` package can generate index for `mypy_boto3_elasticache` and other installed services.

```bash
# Run this command when you add or remove service packages
python -m mypy_boto3
```

Generated index provides overloads for `boto3.client` and `boto3.service`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully
- `VSCode` does not currently support function overloads

Also, generated index allows you to import types from `mypy_boto3`:

```python
# you can replace imports
import mypy_boto3_elasticache as elasticache
from mypy_boto3_elasticache import ElastiCacheClient

# with these
from mypy_boto3 import elasticache
from mypy_boto3.elasticache import ElastiCacheClient
```